@@ -2,10 +2,13 @@
 
 ClickableImage::ClickableImage(QWidget *parent) : QLabel(parent)
 {
+    timer = new QTimer;
+    connect(timer, SIGNAL(timeout()), this, SLOT(timeout()));
 }
 
 void ClickableImage::mousePressEvent(QMouseEvent *eve )
 {
+    timer->start(1000);
         if ( eve->button() == Qt::LeftButton )
         emit leftButtonPressed(this);
         else if ( eve->button() == Qt::RightButton )
@@ -17,7 +20,20 @@ void ClickableImage::mousePressEvent(QMouseEvent *eve )
 void ClickableImage::mouseReleaseEvent(QMouseEvent *eve )
 {
         if ( eve->button() == Qt::LeftButton )
-        emit leftButtonReleased(this);
+         {
+            if (timer->isActive())
+            {
+                timer->stop();
+                emit leftButtonReleased(this);
+            }
+            else
+
+            {
+
+                timer->stop();
+            }
+        }
+
         else if ( eve->button() == Qt::RightButton )
                 emit rightButtonReleased(this);
         else if ( eve->button() == Qt::MidButton )
@@ -33,3 +49,9 @@ void ClickableImage::leaveEvent(QEvent* eve)
 {
         emit mouseLeft(this);
 }
+
+void ClickableImage::timeout()
+{
+    emit leftButtonHold(this);
+    timer->stop();
+}
